function [residual, g1, g2, g3] = banks_exp_K_b_est_gdp_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 119, 1);

%
% Model equations
%

eps_z_ss__ = 1.0000000;
eps_h_ss__ = 1;
r_dlv_ss__ = 1/params(19)-1;
r_deu_ss__ = 1/params(19)-1;
r_ss__ = (1+params(12))/params(12)*r_dlv_ss__;
r_f_ss__ = params(61)*exp(params(59)*params(83));
r_b_ss__ = r_f_ss__*(1+params(59)*params(83));
r_bh_ss__ = r_b_ss__/(1-1/params(10));
r_be_ss__ = r_b_ss__/(1-1/params(11));
ZETA0__ = params(36)*params(29)/(1-(1-params(31))*(params(36)+(1/(1+r_be_ss__)-params(36))*y(77)))/params(49);
ZETA1__ = params(36)*params(30)/(1-(params(36)+(1/(1+r_be_ss__)-params(36))*y(77))*(1-params(32)));
ZETA2__ = eps_z_ss__*eps_h_ss__*(1-params(18))/((1-params(19)*(1-params(17)))*(1-params(19)*params(18)));
ZETA3__ = eps_z_ss__*eps_h_ss__*(1-params(24))/(1-(1-params(17))*params(25)-(1-params(17))*y(76)*(1/(1+r_bh_ss__)-params(25)))/(1-params(24)*params(25));
CHI1__ = 1+params(17)*ZETA2__-ZETA2__*params(17)*((1-params(30))*params(28)/params(73)+(1-params(32))*params(34)*r_deu_ss__*(1-params(44))*ZETA1__/(1+r_be_ss__));
CHI2__ = params(17)*((1-params(30))*params(28)/params(73)+(1-params(32))*params(34)*r_deu_ss__*(1-params(44))*ZETA1__/(1+r_be_ss__))*ZETA3__+ZETA3__*(1-params(17))*params(23)*(1-params(44))*r_deu_ss__/(1+r_bh_ss__);
CHI3__ = (params(49)-1+params(28)*(1-params(29))/params(72)+params(49)*r_deu_ss__/(1+r_be_ss__)*((1-params(31))*params(34)*(1-params(44))*ZETA0__-params(83)*params(49)*r_deu_ss__))/params(49);
CHI4__ = 1+ZETA3__*(params(17)+params(17)*(-(1-params(30)))*(1-params(28))/params(75)+(1-params(17))*params(23)*r_bh_ss__/(1+r_bh_ss__));
CHI5__ = ZETA2__*params(17)*(1-params(30))*(1-params(28))/params(75);
CHI6__ = (1-params(29))*(1-params(28))/(params(49)*params(72));
CY__ = (CHI3__*CHI4__+CHI2__*CHI6__)/(CHI4__*CHI1__-CHI2__*CHI5__);
CYPRIME__ = (CHI6__*CHI1__+CHI3__*CHI5__)/(CHI4__*CHI1__-CHI2__*CHI5__);
QIY__ = params(17)*(ZETA2__*CY__+ZETA3__*CYPRIME__);
RATION__ = params(49)*(1-params(30))*params(72)/params(73)/(1-params(29))*QIY__;
NHNC__ = RATION__^(1/(1+params(20)));
l_pc_ss__ = (params(28)*(1-params(29))*(1-params(19)*params(18))/(1-params(18))/CY__/params(49)/params(72)/(1+RATION__)^((params(21)-params(20))/(1+params(20))))^(1/(1+params(21)));
l_ph_ss__ = l_pc_ss__*NHNC__;
RATION1__ = params(49)*QIY__*(1-params(30))*params(74)/params(75)/(1-params(29));
NHNC1__ = RATION1__^(1/(1+params(26)));
l_ic_ss__ = ((1-params(28))*(1-params(29))*(1-params(24)*params(25))/(1-params(24))/CYPRIME__/params(49)/params(74)/(1+RATION1__)^((params(27)-params(26))/(1+params(26))))^(1/(1+params(27)));
l_ih_ss__ = l_ic_ss__*NHNC1__;
Y_ss__ = l_pc_ss__^params(28)*l_ic_ss__^(1-params(28))*ZETA0__^(params(29)/(1-params(29)));
IH_ss__ = (l_ph_ss__^params(28)*l_ih_ss__^(1-params(28)))^(1-params(30))*(QIY__*ZETA1__*Y_ss__)^params(30);
q_h_ss__ = QIY__*Y_ss__/IH_ss__;
QI__ = QIY__*Y_ss__;
k_c_ss__ = ZETA0__*Y_ss__;
k_h_ss__ = ZETA1__*QI__;
i_c_ss__ = params(31)*k_c_ss__;
i_h_ss__ = params(32)*k_h_ss__;
c_p_ss__ = CY__*Y_ss__;
c_i_ss__ = CYPRIME__*Y_ss__;
h_p_ss__ = ZETA2__*c_p_ss__/q_h_ss__;
h_i_ss__ = ZETA3__*c_i_ss__/q_h_ss__;
b_h_ss__ = (1-params(17))*q_h_ss__*params(23)*1/(1+r_bh_ss__)*h_i_ss__;
b_e_ss__ = params(34)*(k_c_ss__*(1-params(31))*params(79)+k_h_ss__*(1-params(32))*params(80))/(1+r_be_ss__);
c_e_ss__ = params(29)*Y_ss__/params(49)+IH_ss__*params(30)*q_h_ss__-k_c_ss__*params(31)*params(79)-k_h_ss__*params(32)*params(80)-r_be_ss__*b_e_ss__;
C_ss__ = c_p_ss__+c_i_ss__+c_e_ss__;
B_ss__ = b_e_ss__+b_h_ss__;
K_b_ss__ = params(44)*B_ss__;
F_ss__ = params(83)*Y_ss__;
K_B_ss__ = K_b_ss__/B_ss__;
D_ss__ = (1-params(44))*B_ss__-F_ss__;
D_lv_ss__ = D_ss__/2;
D_eu_ss__ = D_ss__/2;
kapa_f__ = (r_ss__-r_b_ss__+D_ss__*params(42)/2)/F_ss__;
Y_star_ss__ = params(66);
neer_ss__ = 1;
Y_ex_ss__ = params(41)*C_ss__*neer_ss__+r_f_ss__*F_ss__;
alpha_star__ = Y_ex_ss__/Y_star_ss__;
GDP_ss__ = Y_ex_ss__+(c_p_ss__+c_i_ss__+c_e_ss__)*(1-params(41))+i_c_ss__+i_h_ss__+IH_ss__*q_h_ss__;
J_b_ss__ = r_be_ss__*b_e_ss__+r_bh_ss__*b_h_ss__-r_dlv_ss__*D_lv_ss__-r_deu_ss__*D_eu_ss__-Y_ss__*params(83)*r_f_ss__-params(42)/2*(D_lv_ss__^2+D_eu_ss__^2)-kapa_f__/2*(params(83)*Y_ss__)^2;
ome_b__ = K_b_ss__*params(56)/J_b_ss__;
T185 = (1-params(30))*params(72)/params(73)/(1-params(29));
T196 = params(28)*(1-params(29))*(1-params(19)*params(18))/(1-params(18));
T199 = T196/CY__/params(49)/params(72);
T203 = (params(21)-params(20))/(1+params(20));
T204 = (1+RATION__)^T203;
T215 = (1-params(30))*params(74)/params(75)/(1-params(29));
T225 = (1-params(28))*(1-params(29))*(1-params(24)*params(25))/(1-params(24));
T228 = T225/CYPRIME__/params(49)/params(74);
T232 = (params(27)-params(26))/(1+params(26));
T233 = (1+RATION1__)^T232;
T242 = l_ic_ss__^(1-params(28));
T245 = ZETA0__^(params(29)/(1-params(29)));
T250 = l_ih_ss__^(1-params(28));
T251 = l_ph_ss__^params(28)*T250;
T357 = params(42)/2;
T364 = kapa_f__/2;
T398 = y(33)^(1+params(20))+y(35)^(1+params(20));
T399 = T398^T203;
T400 = y(60)*T399;
T401 = y(33)^params(20);
T408 = y(35)^params(20);
T439 = y(86)/y(64);
T441 = y(80)*(1+y(73))*T439;
T496 = y(40)^(1+params(26))+y(42)^(1+params(26));
T497 = T496^T232;
T498 = y(60)*T497;
T499 = y(40)^params(26);
T504 = y(42)^params(26);
T519 = y(40)^(1-params(28));
T520 = y(78)*y(33)^params(28)*T519;
T523 = y(46)^params(29);
T530 = y(42)^(1-params(28));
T531 = y(79)*y(35)^params(28)*T530;
T534 = y(48)^params(30);
T542 = y(82)/y(64);
T771 = (1+y(66))^params(37)*(1+r_ss__)^(1-params(37));
T906 = params(43)/2*(y(94)-params(44)*exp(y(114)))^2;
T914 = (y(45)*y(75))^2;
T1058 = (y(65)/y(93))^(-params(68));
T1096 = y(94)/K_B_ss__;
T1101 = y(29)/C_ss__;
T1118 = y(56)/q_h_ss__;
T1123 = y(86)/b_h_ss__;
T1128 = y(82)/b_e_ss__;
T1133 = y(87)/D_lv_ss__;
T1138 = y(88)/D_eu_ss__;
T1152 = y(54)/GDP_ss__;
T1157 = y(49)/c_e_ss__;
T1162 = y(37)/c_i_ss__;
T1167 = y(30)/c_p_ss__;
T1172 = y(38)/h_i_ss__;
T1178 = y(31)/h_p_ss__;
T1183 = y(57)/i_c_ss__;
T1188 = y(58)/i_h_ss__;
T1193 = y(47)/IH_ss__;
T1198 = y(55)/J_b_ss__;
T1203 = y(52)/K_b_ss__;
T1218 = y(53)/B_ss__;
T1233 = y(95)/F_ss__;
T1346 = getPowerDeriv(T398,T203,1);
T1357 = getPowerDeriv(T520,1-params(29),1);
T1378 = getPowerDeriv(T531,1-params(30),1);
T1430 = getPowerDeriv(T496,T232,1);
T1657 = getPowerDeriv(y(65)/y(93),(-params(68)),1);
T1754 = (-(eps_z_ss__*eps_h_ss__*(1-params(24))*(-((1-params(17))*(1/(1+r_bh_ss__)-params(25))))))/((1-(1-params(17))*params(25)-(1-params(17))*y(76)*(1/(1+r_bh_ss__)-params(25)))*(1-(1-params(17))*params(25)-(1-params(17))*y(76)*(1/(1+r_bh_ss__)-params(25))))/(1-params(24)*params(25));
T1755 = (params(17)+params(17)*(-(1-params(30)))*(1-params(28))/params(75)+(1-params(17))*params(23)*r_bh_ss__/(1+r_bh_ss__))*T1754;
T1759 = params(17)*((1-params(30))*params(28)/params(73)+(1-params(32))*params(34)*r_deu_ss__*(1-params(44))*ZETA1__/(1+r_be_ss__))*T1754+(1-params(17))*params(23)*(1-params(44))*r_deu_ss__/(1+r_bh_ss__)*T1754;
T1769 = ((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI3__*T1755+CHI6__*T1759)-(CHI3__*CHI4__+CHI2__*CHI6__)*(CHI1__*T1755-CHI5__*T1759))/((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI4__*CHI1__-CHI2__*CHI5__));
T1779 = (-((CHI6__*CHI1__+CHI3__*CHI5__)*(CHI1__*T1755-CHI5__*T1759)))/((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI4__*CHI1__-CHI2__*CHI5__));
T1786 = params(49)*T185*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779);
T1794 = getPowerDeriv(T199/T204,1/(1+params(21)),1);
T1795 = (T204*(-(T196*T1769))/(CY__*CY__)/params(49)/params(72)-T199*T1786*getPowerDeriv(1+RATION__,T203,1))/(T204*T204)*T1794;
T1805 = params(49)*T215*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779);
T1813 = getPowerDeriv(T228/T233,1/(1+params(27)),1);
T1814 = (T233*(-(T225*T1779))/(CYPRIME__*CYPRIME__)/params(49)/params(74)-T228*T1805*getPowerDeriv(1+RATION1__,T232,1))/(T233*T233)*T1813;
T1820 = T245*(T242*T1795*getPowerDeriv(l_pc_ss__,params(28),1)+l_pc_ss__^params(28)*T1814*getPowerDeriv(l_ic_ss__,1-params(28),1));
T1830 = params(34)*((1-params(31))*params(79)*ZETA0__*T1820+(1-params(32))*params(80)*ZETA1__*(Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*T1820))/(1+r_be_ss__);
T1831 = getPowerDeriv(RATION__,1/(1+params(20)),1);
T1838 = getPowerDeriv(RATION1__,1/(1+params(26)),1);
T1858 = (QIY__*ZETA1__*Y_ss__)^params(30)*(T250*(NHNC__*T1795+l_pc_ss__*T1786*T1831)*getPowerDeriv(l_ph_ss__,params(28),1)+l_ph_ss__^params(28)*(NHNC1__*T1814+l_ic_ss__*T1805*T1838)*getPowerDeriv(l_ih_ss__,1-params(28),1))*getPowerDeriv(T251,1-params(30),1)+T251^(1-params(30))*(ZETA1__*Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*ZETA1__*T1820)*getPowerDeriv(QIY__*ZETA1__*Y_ss__,params(30),1);
T1863 = (IH_ss__*(Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*T1820)-QIY__*Y_ss__*T1858)/(IH_ss__*IH_ss__);
T1876 = (q_h_ss__*(c_i_ss__*T1754+ZETA3__*(Y_ss__*T1779+CYPRIME__*T1820))-ZETA3__*c_i_ss__*T1863)/(q_h_ss__*q_h_ss__);
T1879 = h_i_ss__*(1-params(17))*params(23)*1/(1+r_bh_ss__)*T1863+(1-params(17))*q_h_ss__*params(23)*1/(1+r_bh_ss__)*T1876;
T1880 = T1830+T1879;
T1890 = (F_ss__*params(42)*((1-params(44))*T1880-params(83)*T1820)/2-(r_ss__-r_b_ss__+D_ss__*params(42)/2)*params(83)*T1820)/(F_ss__*F_ss__);
T1892 = y(45)*y(75)*T1890;
T1893 = (-T1892);
T1899 = ((1-params(44))*T1880-params(83)*T1820)/2;
T1919 = r_be_ss__*T1830+r_bh_ss__*T1879-r_dlv_ss__*T1899-r_deu_ss__*T1899-params(83)*r_f_ss__*T1820-T357*(T1899*2*D_lv_ss__+T1899*2*D_eu_ss__)-((params(83)*Y_ss__)^2*T1890/2+T364*params(83)*T1820*2*params(83)*Y_ss__);
T1944 = params(29)*T1820/params(49)+params(30)*q_h_ss__*T1858+IH_ss__*params(30)*T1863-params(31)*params(79)*ZETA0__*T1820-params(32)*params(80)*ZETA1__*(Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*T1820)-r_be_ss__*T1830;
T1945 = Y_ss__*T1779+CYPRIME__*T1820+Y_ss__*T1769+CY__*T1820+T1944;
T2123 = (-(params(36)*params(29)*(-((1-params(31))*(1/(1+r_be_ss__)-params(36))))))/((1-(1-params(31))*(params(36)+(1/(1+r_be_ss__)-params(36))*y(77)))*(1-(1-params(31))*(params(36)+(1/(1+r_be_ss__)-params(36))*y(77))))/params(49);
T2126 = params(49)*r_deu_ss__/(1+r_be_ss__)*(1-params(31))*params(34)*(1-params(44))*T2123/params(49);
T2133 = (-(params(36)*params(30)*(-((1/(1+r_be_ss__)-params(36))*(1-params(32))))))/((1-(params(36)+(1/(1+r_be_ss__)-params(36))*y(77))*(1-params(32)))*(1-(params(36)+(1/(1+r_be_ss__)-params(36))*y(77))*(1-params(32))));
T2136 = params(17)*(1-params(32))*params(34)*r_deu_ss__*(1-params(44))*T2133/(1+r_be_ss__);
T2148 = ((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI4__*T2126+CHI6__*ZETA3__*T2136)-(CHI3__*CHI4__+CHI2__*CHI6__)*(CHI4__*(-(ZETA2__*T2136))-CHI5__*ZETA3__*T2136))/((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI4__*CHI1__-CHI2__*CHI5__));
T2161 = ((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI6__*(-(ZETA2__*T2136))+CHI5__*T2126)-(CHI6__*CHI1__+CHI3__*CHI5__)*(CHI4__*(-(ZETA2__*T2136))-CHI5__*ZETA3__*T2136))/((CHI4__*CHI1__-CHI2__*CHI5__)*(CHI4__*CHI1__-CHI2__*CHI5__));
T2172 = T1794*(T204*(-(T196*T2148))/(CY__*CY__)/params(49)/params(72)-T199*getPowerDeriv(1+RATION__,T203,1)*params(49)*T185*params(17)*(ZETA2__*T2148+ZETA3__*T2161))/(T204*T204);
T2186 = T1813*(T233*(-(T225*T2161))/(CYPRIME__*CYPRIME__)/params(49)/params(74)-T228*getPowerDeriv(1+RATION1__,T232,1)*params(49)*T215*params(17)*(ZETA2__*T2148+ZETA3__*T2161))/(T233*T233);
T2195 = T245*(T242*getPowerDeriv(l_pc_ss__,params(28),1)*T2172+l_pc_ss__^params(28)*getPowerDeriv(l_ic_ss__,1-params(28),1)*T2186)+l_pc_ss__^params(28)*T242*T2123*getPowerDeriv(ZETA0__,params(29)/(1-params(29)),1);
T2209 = params(34)*((1-params(31))*params(79)*(Y_ss__*T2123+ZETA0__*T2195)+(1-params(32))*params(80)*(QI__*T2133+ZETA1__*(Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*T2195)))/(1+r_be_ss__);
T2233 = (QIY__*ZETA1__*Y_ss__)^params(30)*getPowerDeriv(T251,1-params(30),1)*(T250*getPowerDeriv(l_ph_ss__,params(28),1)*(NHNC__*T2172+l_pc_ss__*T1831*params(49)*T185*params(17)*(ZETA2__*T2148+ZETA3__*T2161))+l_ph_ss__^params(28)*getPowerDeriv(l_ih_ss__,1-params(28),1)*(NHNC1__*T2186+l_ic_ss__*T1838*params(49)*T215*params(17)*(ZETA2__*T2148+ZETA3__*T2161)))+T251^(1-params(30))*getPowerDeriv(QIY__*ZETA1__*Y_ss__,params(30),1)*(ZETA1__*Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*(Y_ss__*T2133+ZETA1__*T2195));
T2237 = (IH_ss__*(Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*T2195)-QIY__*Y_ss__*T2233)/(IH_ss__*IH_ss__);
T2250 = h_i_ss__*(1-params(17))*params(23)*1/(1+r_bh_ss__)*T2237+(1-params(17))*q_h_ss__*params(23)*1/(1+r_bh_ss__)*(q_h_ss__*ZETA3__*(Y_ss__*T2161+CYPRIME__*T2195)-ZETA3__*c_i_ss__*T2237)/(q_h_ss__*q_h_ss__);
T2251 = T2209+T2250;
T2260 = (F_ss__*params(42)*((1-params(44))*T2251-params(83)*T2195)/2-(r_ss__-r_b_ss__+D_ss__*params(42)/2)*params(83)*T2195)/(F_ss__*F_ss__);
T2262 = y(45)*y(75)*T2260;
T2263 = (-T2262);
T2269 = ((1-params(44))*T2251-params(83)*T2195)/2;
T2286 = r_be_ss__*T2209+r_bh_ss__*T2250-r_dlv_ss__*T2269-r_deu_ss__*T2269-params(83)*r_f_ss__*T2195-T357*(2*D_lv_ss__*T2269+2*D_eu_ss__*T2269)-((params(83)*Y_ss__)^2*T2260/2+T364*2*params(83)*Y_ss__*params(83)*T2195);
T2310 = params(29)*T2195/params(49)+params(30)*q_h_ss__*T2233+IH_ss__*params(30)*T2237-params(31)*params(79)*(Y_ss__*T2123+ZETA0__*T2195)-params(32)*params(80)*(QI__*T2133+ZETA1__*(Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*T2195))-r_be_ss__*T2209;
T2311 = Y_ss__*T2161+CYPRIME__*T2195+Y_ss__*T2148+CY__*T2195+T2310;
T2537 = (-(params(2)*1/y(81)));
T2543 = (-(params(4)*1/y(81)));
T2556 = 1/y(64);
T2568 = 1/y(83)-params(62)*1/y(83);
lhs =y(36);
rhs =y(60)/(y(30)-params(18)*y(30))-params(18)*params(19)*y(60)/(y(30)-params(18)*y(30));
residual(1)= lhs-rhs;
lhs =y(60)*y(61)/y(31);
rhs =y(36)*y(56)-(1-params(17))*y(56)*params(19)*y(36);
residual(2)= lhs-rhs;
lhs =T400*T401;
rhs =y(36)*y(32)/y(15);
residual(3)= lhs-rhs;
lhs =T400*T408;
rhs =y(36)*y(34)/y(16);
residual(4)= lhs-rhs;
lhs =y(36);
rhs =params(19)*y(36)*(1+y(70))*y(80)/(y(80)*y(81));
residual(5)= lhs-rhs;
lhs =y(36);
rhs =params(19)*y(36)*(1+y(71))/y(81);
residual(6)= lhs-rhs;
lhs =y(37)+y(56)*(y(38)-(1-params(17))*y(38))+T441/(y(80)*y(81));
rhs =T439+y(39)*y(40)/y(17)+y(41)*y(42)/y(18);
residual(7)= lhs-rhs;
lhs =(1+y(73))*y(86)/y(64);
rhs =y(38)*(1-params(17))*y(81)*y(76)*y(56);
residual(8)= lhs-rhs;
lhs =y(76);
rhs =params(23)*(1-params(22))+y(76)*params(22)+x(2);
residual(9)= lhs-rhs;
lhs =y(43);
rhs =y(60)/(y(37)-params(24)*y(37))-params(24)*params(25)*y(60)/(y(37)-params(24)*y(37));
residual(10)= lhs-rhs;
lhs =y(60)*y(61)/y(38);
rhs =y(56)*y(43)-(1-params(17))*y(56)*params(25)*y(43)-(1-params(17))*y(81)*y(56)*y(76)*y(44);
residual(11)= lhs-rhs;
lhs =T498*T499;
rhs =y(39)*y(43)/y(17);
residual(12)= lhs-rhs;
lhs =T498*T504;
rhs =y(41)*y(43)/y(18);
residual(13)= lhs-rhs;
lhs =y(43);
rhs =y(80)*(1+y(73))*params(25)*y(43)/(y(80)*y(81))+(1+y(73))*y(44);
residual(14)= lhs-rhs;
lhs =y(45);
rhs =T520^(1-params(29))*T523;
residual(15)= lhs-rhs;
lhs =y(47);
rhs =T531^(1-params(30))*T534;
residual(16)= lhs-rhs;
lhs =y(45)/y(62)+y(56)*y(47)+T542;
rhs =y(41)*y(42)+y(39)*y(40)+y(49)+y(33)*y(32)+y(35)*y(34)+y(89)*(y(46)-(1-params(31))*y(46))+y(90)*(y(48)-(1-params(32))*y(48))+y(80)*T542*(1+y(74))/(y(80)*y(81));
residual(17)= lhs-rhs;
lhs =T542;
rhs =y(77)*y(81)*(y(46)*(1-params(31))*y(89)+y(48)*(1-params(32))*y(90))/(1+y(74));
residual(18)= lhs-rhs;
lhs =y(77);
rhs =params(34)*(1-params(33))+y(77)*params(33)+x(3);
residual(19)= lhs-rhs;
lhs =y(50);
rhs =1/(y(49)-y(49)*params(35))-params(36)*params(35)/(y(49)-y(49)*params(35));
residual(20)= lhs-rhs;
lhs =params(28)*(1-params(29))*y(45);
rhs =y(33)*y(32)*y(62);
residual(21)= lhs-rhs;
lhs =(1-params(29))*(1-params(28))*y(45);
rhs =y(40)*y(39)*y(62);
residual(22)= lhs-rhs;
lhs =y(47)*(1-params(30))*params(28)*y(56);
rhs =y(35)*y(34);
residual(23)= lhs-rhs;
lhs =y(47)*(1-params(30))*(1-params(28))*y(56);
rhs =y(41)*y(42);
residual(24)= lhs-rhs;
residual(25) = y(45)*params(36)*params(29)*y(50)/(y(46)*y(62))-y(89)*y(50)+y(89)*(1-params(31))*params(36)*y(50)+(1-params(31))*y(89)*y(81)*y(77)*y(51);
residual(26) = y(47)*y(56)*params(36)*params(30)*y(50)/y(48)-y(90)*y(50)+y(90)*(1-params(32))*params(36)*y(50)+(1-params(32))*y(90)*y(81)*y(77)*y(51);
residual(27) = y(50)-y(80)*(1+y(74))*params(36)*y(50)/(y(80)*y(81))-(1+y(74))*y(51);
lhs =log(y(83))-log(y(83))*params(62);
rhs =params(19)*(log(y(83))-log(y(83))*params(62))-(1-params(63))*(1-params(19)*params(63))/params(63)*log(y(62)/params(49))+x(4);
residual(28)= lhs-rhs;
lhs =log(y(11))-params(2)*log(y(81));
rhs =params(19)*(log(y(11))-params(2)*log(y(81)))-(1-params(3))*(1-params(19)*params(3))/params(3)*log(y(15)/params(72))+x(19);
residual(29)= lhs-rhs;
lhs =log(y(12))-params(2)*log(y(81));
rhs =params(25)*(log(y(12))-params(2)*log(y(81)))-(1-params(3))*(1-params(25)*params(3))/params(3)*log(y(17)/params(74))+x(20);
residual(30)= lhs-rhs;
lhs =log(y(13))-log(y(81))*params(4);
rhs =params(19)*(log(y(13))-log(y(81))*params(4))-(1-params(5))*(1-params(19)*params(5))/params(5)*log(y(16)/params(73))+x(21);
residual(31)= lhs-rhs;
lhs =log(y(14))-log(y(81))*params(4);
rhs =params(25)*(log(y(14))-log(y(81))*params(4))-(1-params(5))*(1-params(25)*params(5))/params(5)*log(y(18)/params(75))+x(22);
residual(32)= lhs-rhs;
lhs =y(11);
rhs =y(32)*y(81)/y(32);
residual(33)= lhs-rhs;
lhs =y(12);
rhs =y(81)*y(39)/y(39);
residual(34)= lhs-rhs;
lhs =y(13);
rhs =y(34)*y(81)/y(34);
residual(35)= lhs-rhs;
lhs =y(14);
rhs =y(81)*y(41)/y(41);
residual(36)= lhs-rhs;
lhs =y(46);
rhs =(1-params(31))*y(46)+y(57);
residual(37)= lhs-rhs;
lhs =y(48);
rhs =(1-params(32))*y(48)+y(58);
residual(38)= lhs-rhs;
lhs =y(89);
rhs =1;
residual(39)= lhs-rhs;
lhs =y(90);
rhs =1;
residual(40)= lhs-rhs;
lhs =1+y(66);
rhs =T771*y(81)^((1-params(37))*params(38))*exp(x(5));
residual(41)= lhs-rhs;
lhs =y(83);
rhs =y(84)+y(4)-y(85);
residual(42)= lhs-rhs;
lhs =y(83);
rhs =y(81)-params(41)*y(85);
residual(43)= lhs-rhs;
lhs =y(67);
rhs =y(68)*y(63);
residual(44)= lhs-rhs;
lhs =y(63);
rhs =exp(params(59)*y(75)+y(91));
residual(45)= lhs-rhs;
lhs =y(53);
rhs =y(87)+y(88)+y(45)*y(75)+y(52);
residual(46)= lhs-rhs;
lhs =y(72);
rhs =y(67)*(1+params(59)*y(75))-(params(42)*y(88)-y(45)*kapa_f__*y(75));
residual(47)= lhs-rhs;
lhs =y(66);
rhs =y(45)*kapa_f__*y(75)+y(80)*y(67)*(1+params(59)*y(75))/y(80)-params(42)*y(87);
residual(48)= lhs-rhs;
lhs =y(80)*y(69)/y(80)-y(66);
rhs =params(42)*y(87)+(-params(43))*(y(94)-params(44)*exp(y(114)))*y(94)^2-y(45)*kapa_f__*y(75);
residual(49)= lhs-rhs;
residual(50) = 1-y(19)+y(69)*y(19)/y(73);
residual(51) = 1-y(20)+y(69)*y(20)/y(74);
residual(52) = y(66)*y(21)/y(71)-1-y(21);
residual(53) = y(80)*y(72)*y(22)/y(70)/y(80)-y(80)*(1+y(22))/y(80);
lhs =y(52);
rhs =y(52)*exp((-y(115)))*(1-params(56))+ome_b__*y(55);
residual(54)= lhs-rhs;
lhs =y(55);
rhs =y(73)*y(86)+y(82)*y(74)-y(71)*y(87)-y(70)*y(88)-y(45)*y(67)*y(75)-y(52)*T906-T357*(y(87)^2+y(88)^2)-T364*T914;
residual(55)= lhs-rhs;
lhs =y(54);
rhs =y(56)*y(47)+y(58)+y(57)+(1-params(41))*(y(49)+y(30)+y(37))+y(59);
residual(56)= lhs-rhs;
lhs =y(47);
rhs =y(31)+y(38)-(1-params(17))*(y(31)+y(38));
residual(57)= lhs-rhs;
lhs =y(53);
rhs =y(86)+y(82);
residual(58)= lhs-rhs;
lhs =y(29);
rhs =y(49)+y(30)+y(37);
residual(59)= lhs-rhs;
lhs =y(92);
rhs =params(66)*(1-params(67))+y(92)*params(67)+x(13);
residual(60)= lhs-rhs;
lhs =y(68);
rhs =params(61)*(1-params(55))+y(68)*params(55)+x(11);
residual(61)= lhs-rhs;
lhs =y(85);
rhs =y(85)*params(50)+x(6);
residual(62)= lhs-rhs;
lhs =log(y(78));
rhs =log(y(78))*params(51)+x(7);
residual(63)= lhs-rhs;
lhs =log(y(79));
rhs =log(y(79))*params(52)+x(8);
residual(64)= lhs-rhs;
lhs =log(y(60));
rhs =log(y(60))*params(53)+x(9);
residual(65)= lhs-rhs;
lhs =log(y(61));
rhs =log(y(61))*params(54)+x(10);
residual(66)= lhs-rhs;
lhs =y(91);
rhs =y(91)*params(65)+x(12);
residual(67)= lhs-rhs;
lhs =1-y(84);
rhs =(1-y(84))*params(69)+x(14);
residual(68)= lhs-rhs;
lhs =y(19);
rhs =params(10)*(1-params(6))+y(19)*params(6)+x(15);
residual(69)= lhs-rhs;
lhs =y(20);
rhs =params(11)*(1-params(7))+y(20)*params(7)+x(16);
residual(70)= lhs-rhs;
lhs =y(21);
rhs =params(12)*(1-params(8))+y(21)*params(8)+x(17);
residual(71)= lhs-rhs;
lhs =y(22);
rhs =(1-params(9))*params(13)+y(22)*params(9)+x(18);
residual(72)= lhs-rhs;
lhs =y(116);
rhs =y(80)*params(84)+(1-params(84))*y(117);
residual(73)= lhs-rhs;
lhs =0;
rhs =x(25)+params(1)*(y(117)-y(119));
residual(74)= lhs-rhs;
residual(75) = y(4);
lhs =y(81);
rhs =1;
residual(76)= lhs-rhs;
lhs =y(83);
rhs =1;
residual(77)= lhs-rhs;
lhs =y(84);
rhs =1;
residual(78)= lhs-rhs;
lhs =y(94);
rhs =y(52)/y(53);
residual(79)= lhs-rhs;
lhs =y(95);
rhs =y(45)*y(75);
residual(80)= lhs-rhs;
lhs =y(59);
rhs =y(92)*alpha_star__*T1058;
residual(81)= lhs-rhs;
lhs =y(59)-y(116)*params(41)*y(29);
rhs =(-(y(95)-y(80)*y(95)*(1+y(67))/y(80)));
residual(82)= lhs-rhs;
lhs =y(3);
rhs =(y(73)-y(68))*100;
residual(83)= lhs-rhs;
lhs =y(2);
rhs =100*(y(74)-y(68));
residual(84)= lhs-rhs;
lhs =y(1);
rhs =100*(y(66)-y(68));
residual(85)= lhs-rhs;
lhs =y(26);
rhs =y(66)*100*4;
residual(86)= lhs-rhs;
lhs =y(27);
rhs =4*y(74)*100;
residual(87)= lhs-rhs;
lhs =y(10);
rhs =100*log(T1096);
residual(88)= lhs-rhs;
lhs =y(28);
rhs =100*log(T1101);
residual(89)= lhs-rhs;
lhs =y(23);
rhs =4*y(73)*100;
residual(90)= lhs-rhs;
lhs =y(24);
rhs =4*y(70)*100;
residual(91)= lhs-rhs;
lhs =y(25);
rhs =4*y(68)*100;
residual(92)= lhs-rhs;
lhs =y(9);
rhs =100*log(T1118);
residual(93)= lhs-rhs;
lhs =y(5);
rhs =100*log(T1123);
residual(94)= lhs-rhs;
lhs =y(6);
rhs =100*log(T1128);
residual(95)= lhs-rhs;
lhs =y(7);
rhs =100*log(T1133);
residual(96)= lhs-rhs;
lhs =y(8);
rhs =100*log(T1138);
residual(97)= lhs-rhs;
lhs =y(98);
rhs =4*y(71)*100;
residual(98)= lhs-rhs;
lhs =y(97);
rhs =4*y(67)*100;
residual(99)= lhs-rhs;
lhs =y(99);
rhs =100*log(T1152);
residual(100)= lhs-rhs;
lhs =y(102);
rhs =100*log(T1157);
residual(101)= lhs-rhs;
lhs =y(103);
rhs =100*log(T1162);
residual(102)= lhs-rhs;
lhs =y(104);
rhs =100*log(T1167);
residual(103)= lhs-rhs;
lhs =y(105);
rhs =100*log(T1172);
residual(104)= lhs-rhs;
lhs =y(106);
rhs =100*log(T1178);
residual(105)= lhs-rhs;
lhs =y(107);
rhs =100*log(T1183);
residual(106)= lhs-rhs;
lhs =y(108);
rhs =100*log(T1188);
residual(107)= lhs-rhs;
lhs =y(109);
rhs =100*log(T1193);
residual(108)= lhs-rhs;
lhs =y(110);
rhs =100*log(T1198);
residual(109)= lhs-rhs;
lhs =y(111);
rhs =100*log(T1203);
residual(110)= lhs-rhs;
lhs =y(112);
rhs =100*log(y(89)/params(79));
residual(111)= lhs-rhs;
lhs =y(113);
rhs =100*log(y(90)/params(80));
residual(112)= lhs-rhs;
lhs =y(101);
rhs =100*log(T1218);
residual(113)= lhs-rhs;
lhs =y(100);
rhs =100*log(y(81)/params(78));
residual(114)= lhs-rhs;
lhs =y(118);
rhs =100*log(y(84));
residual(115)= lhs-rhs;
lhs =y(96);
rhs =100*log(T1233);
residual(116)= lhs-rhs;
lhs =y(114);
rhs =y(114)*params(81)+x(23);
residual(117)= lhs-rhs;
lhs =y(115);
rhs =y(115)*params(82)+x(24)/5;
residual(118)= lhs-rhs;
lhs =y(119);
rhs =y(117);
residual(119)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(119, 119);

  %
  % Jacobian matrix
  %

  g1(1,30)=(-((-((1-params(18))*y(60)))/((y(30)-params(18)*y(30))*(y(30)-params(18)*y(30)))-(-((1-params(18))*params(18)*params(19)*y(60)))/((y(30)-params(18)*y(30))*(y(30)-params(18)*y(30)))));
  g1(1,36)=1;
  g1(1,60)=(-(1/(y(30)-params(18)*y(30))-params(19)*params(18)/(y(30)-params(18)*y(30))));
  g1(2,31)=(-(y(60)*y(61)))/(y(31)*y(31));
  g1(2,36)=(-(y(56)-(1-params(17))*params(19)*y(56)));
  g1(2,56)=(-(y(36)-(1-params(17))*params(19)*y(36)));
  g1(2,60)=y(61)/y(31);
  g1(2,61)=y(60)/y(31);
  g1(3,15)=(-((-(y(36)*y(32)))/(y(15)*y(15))));
  g1(3,32)=(-(y(36)/y(15)));
  g1(3,33)=T401*y(60)*getPowerDeriv(y(33),1+params(20),1)*T1346+T400*getPowerDeriv(y(33),params(20),1);
  g1(3,35)=T401*y(60)*T1346*getPowerDeriv(y(35),1+params(20),1);
  g1(3,36)=(-(y(32)/y(15)));
  g1(3,60)=T399*T401;
  g1(4,16)=(-((-(y(36)*y(34)))/(y(16)*y(16))));
  g1(4,33)=T408*y(60)*getPowerDeriv(y(33),1+params(20),1)*T1346;
  g1(4,34)=(-(y(36)/y(16)));
  g1(4,35)=T408*y(60)*T1346*getPowerDeriv(y(35),1+params(20),1)+T400*getPowerDeriv(y(35),params(20),1);
  g1(4,36)=(-(y(34)/y(16)));
  g1(4,60)=T399*T408;
  g1(5,36)=1-y(80)*params(19)*(1+y(70))/(y(80)*y(81));
  g1(5,70)=(-(params(19)*y(36)*y(80)/(y(80)*y(81))));
  g1(5,80)=(-((params(19)*y(36)*(1+y(70))*y(80)*y(81)-params(19)*y(36)*(1+y(70))*y(80)*y(81))/(y(80)*y(81)*y(80)*y(81))));
  g1(5,81)=(-((-(y(80)*params(19)*y(36)*(1+y(70))*y(80)))/(y(80)*y(81)*y(80)*y(81))));
  g1(6,36)=1-params(19)*(1+y(71))/y(81);
  g1(6,71)=(-(params(19)*y(36)/y(81)));
  g1(6,81)=(-((-(params(19)*y(36)*(1+y(71))))/(y(81)*y(81))));
  g1(7,17)=(-((-(y(39)*y(40)))/(y(17)*y(17))));
  g1(7,18)=(-((-(y(41)*y(42)))/(y(18)*y(18))));
  g1(7,37)=1;
  g1(7,38)=y(56)*(1-(1-params(17)));
  g1(7,39)=(-(y(40)/y(17)));
  g1(7,40)=(-(y(39)/y(17)));
  g1(7,41)=(-(y(42)/y(18)));
  g1(7,42)=(-(y(41)/y(18)));
  g1(7,56)=y(38)-(1-params(17))*y(38);
  g1(7,64)=y(80)*(1+y(73))*(-y(86))/(y(64)*y(64))/(y(80)*y(81))-(-y(86))/(y(64)*y(64));
  g1(7,73)=y(80)*T439/(y(80)*y(81));
  g1(7,80)=(y(80)*y(81)*(1+y(73))*T439-y(81)*T441)/(y(80)*y(81)*y(80)*y(81));
  g1(7,81)=(-(y(80)*T441))/(y(80)*y(81)*y(80)*y(81));
  g1(7,86)=y(80)*(1+y(73))*T2556/(y(80)*y(81))-T2556;
  g1(8,38)=(-((1-params(17))*y(81)*y(76)*y(56)));
  g1(8,56)=(-(y(38)*(1-params(17))*y(76)*y(81)));
  g1(8,64)=(-((1+y(73))*y(86)))/(y(64)*y(64));
  g1(8,73)=T439;
  g1(8,76)=(-(y(38)*(1-params(17))*y(56)*y(81)));
  g1(8,81)=(-(y(38)*(1-params(17))*y(76)*y(56)));
  g1(8,86)=(1+y(73))/y(64);
  g1(9,76)=1-params(22);
  g1(10,37)=(-((-((1-params(24))*y(60)))/((y(37)-params(24)*y(37))*(y(37)-params(24)*y(37)))-(-((1-params(24))*params(24)*params(25)*y(60)))/((y(37)-params(24)*y(37))*(y(37)-params(24)*y(37)))));
  g1(10,43)=1;
  g1(10,60)=(-(1/(y(37)-params(24)*y(37))-params(24)*params(25)/(y(37)-params(24)*y(37))));
  g1(11,38)=(-(y(60)*y(61)))/(y(38)*y(38));
  g1(11,43)=(-(y(56)-(1-params(17))*params(25)*y(56)));
  g1(11,44)=(1-params(17))*y(81)*y(76)*y(56);
  g1(11,56)=(-(y(43)-(1-params(17))*params(25)*y(43)-(1-params(17))*y(81)*y(76)*y(44)));
  g1(11,60)=y(61)/y(38);
  g1(11,61)=y(60)/y(38);
  g1(11,76)=(1-params(17))*y(81)*y(56)*y(44);
  g1(11,81)=(1-params(17))*y(56)*y(76)*y(44);
  g1(12,17)=(-((-(y(39)*y(43)))/(y(17)*y(17))));
  g1(12,39)=(-(y(43)/y(17)));
  g1(12,40)=T499*y(60)*getPowerDeriv(y(40),1+params(26),1)*T1430+T498*getPowerDeriv(y(40),params(26),1);
  g1(12,42)=T499*y(60)*T1430*getPowerDeriv(y(42),1+params(26),1);
  g1(12,43)=(-(y(39)/y(17)));
  g1(12,60)=T497*T499;
  g1(13,18)=(-((-(y(41)*y(43)))/(y(18)*y(18))));
  g1(13,40)=T504*y(60)*getPowerDeriv(y(40),1+params(26),1)*T1430;
  g1(13,41)=(-(y(43)/y(18)));
  g1(13,42)=T504*y(60)*T1430*getPowerDeriv(y(42),1+params(26),1)+T498*getPowerDeriv(y(42),params(26),1);
  g1(13,43)=(-(y(41)/y(18)));
  g1(13,60)=T497*T504;
  g1(14,43)=1-y(80)*params(25)*(1+y(73))/(y(80)*y(81));
  g1(14,44)=(-(1+y(73)));
  g1(14,73)=(-(y(44)+y(80)*params(25)*y(43)/(y(80)*y(81))));
  g1(14,80)=(-((y(80)*y(81)*(1+y(73))*params(25)*y(43)-y(81)*y(80)*(1+y(73))*params(25)*y(43))/(y(80)*y(81)*y(80)*y(81))));
  g1(14,81)=(-((-(y(80)*y(80)*(1+y(73))*params(25)*y(43)))/(y(80)*y(81)*y(80)*y(81))));
  g1(15,33)=(-(T523*T519*y(78)*getPowerDeriv(y(33),params(28),1)*T1357));
  g1(15,40)=(-(T523*T1357*y(78)*y(33)^params(28)*getPowerDeriv(y(40),1-params(28),1)));
  g1(15,45)=1;
  g1(15,46)=(-(T520^(1-params(29))*getPowerDeriv(y(46),params(29),1)));
  g1(15,78)=(-(T523*T1357*y(33)^params(28)*T519));
  g1(16,35)=(-(T534*T530*y(79)*getPowerDeriv(y(35),params(28),1)*T1378));
  g1(16,42)=(-(T534*T1378*y(79)*y(35)^params(28)*getPowerDeriv(y(42),1-params(28),1)));
  g1(16,47)=1;
  g1(16,48)=(-(T531^(1-params(30))*getPowerDeriv(y(48),params(30),1)));
  g1(16,79)=(-(T534*T1378*y(35)^params(28)*T530));
  g1(17,32)=(-y(33));
  g1(17,33)=(-y(32));
  g1(17,34)=(-y(35));
  g1(17,35)=(-y(34));
  g1(17,39)=(-y(40));
  g1(17,40)=(-y(39));
  g1(17,41)=(-y(42));
  g1(17,42)=(-y(41));
  g1(17,45)=1/y(62);
  g1(17,46)=(-(y(89)*(1-(1-params(31)))));
  g1(17,47)=y(56);
  g1(17,48)=(-(y(90)*(1-(1-params(32)))));
  g1(17,49)=(-1);
  g1(17,56)=y(47);
  g1(17,62)=(-y(45))/(y(62)*y(62));
  g1(17,64)=(-y(82))/(y(64)*y(64))-y(80)*(1+y(74))*(-y(82))/(y(64)*y(64))/(y(80)*y(81));
  g1(17,74)=(-(y(80)*T542/(y(80)*y(81))));
  g1(17,80)=(-((y(80)*y(81)*T542*(1+y(74))-y(81)*y(80)*T542*(1+y(74)))/(y(80)*y(81)*y(80)*y(81))));
  g1(17,81)=(-((-(y(80)*y(80)*T542*(1+y(74))))/(y(80)*y(81)*y(80)*y(81))));
  g1(17,82)=T2556-y(80)*(1+y(74))*T2556/(y(80)*y(81));
  g1(17,89)=(-(y(46)-(1-params(31))*y(46)));
  g1(17,90)=(-(y(48)-(1-params(32))*y(48)));
  g1(18,46)=(-(y(77)*y(81)*(1-params(31))*y(89)/(1+y(74))));
  g1(18,48)=(-(y(77)*y(81)*(1-params(32))*y(90)/(1+y(74))));
  g1(18,64)=(-y(82))/(y(64)*y(64));
  g1(18,74)=(-((-(y(77)*y(81)*(y(46)*(1-params(31))*y(89)+y(48)*(1-params(32))*y(90))))/((1+y(74))*(1+y(74)))));
  g1(18,77)=(-(y(81)*(y(46)*(1-params(31))*y(89)+y(48)*(1-params(32))*y(90))/(1+y(74))));
  g1(18,81)=(-(y(77)*(y(46)*(1-params(31))*y(89)+y(48)*(1-params(32))*y(90))/(1+y(74))));
  g1(18,82)=T2556;
  g1(18,89)=(-((1-params(31))*y(46)*y(77)*y(81)/(1+y(74))));
  g1(18,90)=(-((1-params(32))*y(48)*y(77)*y(81)/(1+y(74))));
  g1(19,77)=1-params(33);
  g1(20,49)=(-((-(1-params(35)))/((y(49)-y(49)*params(35))*(y(49)-y(49)*params(35)))-(-(params(36)*params(35)*(1-params(35))))/((y(49)-y(49)*params(35))*(y(49)-y(49)*params(35)))));
  g1(20,50)=1;
  g1(21,32)=(-(y(33)*y(62)));
  g1(21,33)=(-(y(32)*y(62)));
  g1(21,45)=params(28)*(1-params(29));
  g1(21,62)=(-(y(33)*y(32)));
  g1(22,39)=(-(y(40)*y(62)));
  g1(22,40)=(-(y(39)*y(62)));
  g1(22,45)=(1-params(29))*(1-params(28));
  g1(22,62)=(-(y(39)*y(40)));
  g1(23,34)=(-y(35));
  g1(23,35)=(-y(34));
  g1(23,47)=(1-params(30))*params(28)*y(56);
  g1(23,56)=(1-params(30))*params(28)*y(47);
  g1(24,41)=(-y(42));
  g1(24,42)=(-y(41));
  g1(24,47)=(1-params(30))*(1-params(28))*y(56);
  g1(24,56)=(1-params(30))*(1-params(28))*y(47);
  g1(25,45)=params(36)*params(29)*y(50)/(y(46)*y(62));
  g1(25,46)=(-(y(62)*y(45)*params(36)*params(29)*y(50)))/(y(46)*y(62)*y(46)*y(62));
  g1(25,50)=params(36)*params(29)*y(45)/(y(46)*y(62))-y(89)+y(89)*params(36)*(1-params(31));
  g1(25,51)=(1-params(31))*y(89)*y(77)*y(81);
  g1(25,62)=(-(y(46)*y(45)*params(36)*params(29)*y(50)))/(y(46)*y(62)*y(46)*y(62));
  g1(25,77)=(1-params(31))*y(89)*y(81)*y(51);
  g1(25,81)=(1-params(31))*y(89)*y(77)*y(51);
  g1(25,89)=(1-params(31))*params(36)*y(50)+(-y(50))+(1-params(31))*y(81)*y(77)*y(51);
  g1(26,47)=y(56)*params(36)*params(30)*y(50)/y(48);
  g1(26,48)=(-(y(47)*y(56)*params(36)*params(30)*y(50)))/(y(48)*y(48));
  g1(26,50)=y(47)*params(36)*params(30)*y(56)/y(48)-y(90)+y(90)*params(36)*(1-params(32));
  g1(26,51)=(1-params(32))*y(90)*y(77)*y(81);
  g1(26,56)=y(47)*params(36)*params(30)*y(50)/y(48);
  g1(26,77)=(1-params(32))*y(90)*y(81)*y(51);
  g1(26,81)=(1-params(32))*y(90)*y(77)*y(51);
  g1(26,90)=(1-params(32))*params(36)*y(50)+(-y(50))+(1-params(32))*y(81)*y(77)*y(51);
  g1(27,50)=1-y(80)*params(36)*(1+y(74))/(y(80)*y(81));
  g1(27,51)=(-(1+y(74)));
  g1(27,74)=(-(y(80)*params(36)*y(50)/(y(80)*y(81))))-y(51);
  g1(27,80)=(-((y(80)*y(81)*(1+y(74))*params(36)*y(50)-y(81)*y(80)*(1+y(74))*params(36)*y(50))/(y(80)*y(81)*y(80)*y(81))));
  g1(27,81)=(-((-(y(80)*y(80)*(1+y(74))*params(36)*y(50)))/(y(80)*y(81)*y(80)*y(81))));
  g1(28,62)=(1-params(63))*(1-params(19)*params(63))/params(63)*1/params(49)/(y(62)/params(49));
  g1(28,83)=T2568-params(19)*T2568;
  g1(29,11)=1/y(11)-params(19)*1/y(11);
  g1(29,15)=(1-params(3))*(1-params(19)*params(3))/params(3)*1/params(72)/(y(15)/params(72));
  g1(29,81)=T2537-params(19)*T2537;
  g1(30,12)=1/y(12)-params(25)*1/y(12);
  g1(30,17)=(1-params(3))*(1-params(25)*params(3))/params(3)*1/params(74)/(y(17)/params(74));
  g1(30,81)=T2537-params(25)*T2537;
  g1(31,13)=1/y(13)-params(19)*1/y(13);
  g1(31,16)=(1-params(5))*(1-params(19)*params(5))/params(5)*1/params(73)/(y(16)/params(73));
  g1(31,81)=T2543-params(19)*T2543;
  g1(32,14)=1/y(14)-params(25)*1/y(14);
  g1(32,18)=(1-params(5))*(1-params(25)*params(5))/params(5)*1/params(75)/(y(18)/params(75));
  g1(32,81)=T2543-params(25)*T2543;
  g1(33,11)=1;
  g1(33,81)=(-1);
  g1(34,12)=1;
  g1(34,81)=(-1);
  g1(35,13)=1;
  g1(35,81)=(-1);
  g1(36,14)=1;
  g1(36,81)=(-1);
  g1(37,46)=1-(1-params(31));
  g1(37,57)=(-1);
  g1(38,48)=1-(1-params(32));
  g1(38,58)=(-1);
  g1(39,89)=1;
  g1(40,90)=1;
  g1(41,66)=1-exp(x(5))*y(81)^((1-params(37))*params(38))*(1+r_ss__)^(1-params(37))*getPowerDeriv(1+y(66),params(37),1);
  g1(41,81)=(-(exp(x(5))*T771*getPowerDeriv(y(81),(1-params(37))*params(38),1)));
  g1(42,4)=(-1);
  g1(42,83)=1;
  g1(42,84)=(-1);
  g1(42,85)=1;
  g1(43,81)=(-1);
  g1(43,83)=1;
  g1(43,85)=params(41);
  g1(44,63)=(-y(68));
  g1(44,67)=1;
  g1(44,68)=(-y(63));
  g1(45,63)=1;
  g1(45,75)=(-(params(59)*exp(params(59)*y(75)+y(91))));
  g1(45,91)=(-exp(params(59)*y(75)+y(91)));
  g1(46,45)=(-y(75));
  g1(46,52)=(-1);
  g1(46,53)=1;
  g1(46,75)=(-y(45));
  g1(46,87)=(-1);
  g1(46,88)=(-1);
  g1(47,45)=(-(kapa_f__*y(75)));
  g1(47,67)=(-(1+params(59)*y(75)));
  g1(47,72)=1;
  g1(47,75)=(-(params(59)*y(67)-(-(kapa_f__*y(45)))));
  g1(47,76)=T1893;
  g1(47,77)=T2263;
  g1(47,88)=params(42);
  g1(48,45)=(-(kapa_f__*y(75)));
  g1(48,66)=1;
  g1(48,67)=(-(y(80)*(1+params(59)*y(75))/y(80)));
  g1(48,75)=(-(kapa_f__*y(45)+y(80)*params(59)*y(67)/y(80)));
  g1(48,76)=T1893;
  g1(48,77)=T2263;
  g1(48,87)=params(42);
  g1(49,45)=kapa_f__*y(75);
  g1(49,66)=(-1);
  g1(49,69)=1;
  g1(49,75)=kapa_f__*y(45);
  g1(49,76)=T1892;
  g1(49,77)=T2262;
  g1(49,87)=(-params(42));
  g1(49,94)=(-((-params(43))*y(94)^2+(-params(43))*(y(94)-params(44)*exp(y(114)))*2*y(94)));
  g1(49,114)=(-(y(94)^2*(-params(43))*(-(params(44)*exp(y(114))))));
  g1(50,19)=(-1)+y(69)/y(73);
  g1(50,69)=y(19)/y(73);
  g1(50,73)=(-(y(69)*y(19)))/(y(73)*y(73));
  g1(51,20)=(-1)+y(69)/y(74);
  g1(51,69)=y(20)/y(74);
  g1(51,74)=(-(y(69)*y(20)))/(y(74)*y(74));
  g1(52,21)=y(66)/y(71)-1;
  g1(52,66)=y(21)/y(71);
  g1(52,71)=(-(y(66)*y(21)))/(y(71)*y(71));
  g1(53,22)=y(80)*y(72)/y(70)/y(80)-1;
  g1(53,70)=y(80)*(-(y(72)*y(22)))/(y(70)*y(70))/y(80);
  g1(53,72)=y(80)*y(22)/y(70)/y(80);
  g1(54,52)=1-exp((-y(115)))*(1-params(56));
  g1(54,55)=(-ome_b__);
  g1(54,76)=(-(y(55)*(J_b_ss__*params(56)*params(44)*T1880-K_b_ss__*params(56)*T1919)/(J_b_ss__*J_b_ss__)));
  g1(54,77)=(-(y(55)*(J_b_ss__*params(56)*params(44)*T2251-K_b_ss__*params(56)*T2286)/(J_b_ss__*J_b_ss__)));
  g1(54,115)=(-(y(52)*(1-params(56))*(-exp((-y(115))))));
  g1(55,45)=(-((-(y(67)*y(75)))-T364*y(75)*2*y(45)*y(75)));
  g1(55,52)=T906;
  g1(55,55)=1;
  g1(55,67)=y(45)*y(75);
  g1(55,70)=y(88);
  g1(55,71)=y(87);
  g1(55,73)=(-y(86));
  g1(55,74)=(-y(82));
  g1(55,75)=(-((-(y(45)*y(67)))-T364*y(45)*2*y(45)*y(75)));
  g1(55,76)=T914*T1890/2;
  g1(55,77)=T914*T2260/2;
  g1(55,82)=(-y(74));
  g1(55,86)=(-y(73));
  g1(55,87)=(-((-y(71))-T357*2*y(87)));
  g1(55,88)=(-((-y(70))-T357*2*y(88)));
  g1(55,94)=y(52)*params(43)/2*2*(y(94)-params(44)*exp(y(114)));
  g1(55,114)=y(52)*params(43)/2*2*(y(94)-params(44)*exp(y(114)))*(-(params(44)*exp(y(114))));
  g1(56,30)=(-(1-params(41)));
  g1(56,37)=(-(1-params(41)));
  g1(56,47)=(-y(56));
  g1(56,49)=(-(1-params(41)));
  g1(56,54)=1;
  g1(56,56)=(-y(47));
  g1(56,57)=(-1);
  g1(56,58)=(-1);
  g1(56,59)=(-1);
  g1(57,31)=(-(1-(1-params(17))));
  g1(57,38)=(-(1-(1-params(17))));
  g1(57,47)=1;
  g1(58,53)=1;
  g1(58,82)=(-1);
  g1(58,86)=(-1);
  g1(59,29)=1;
  g1(59,30)=(-1);
  g1(59,37)=(-1);
  g1(59,49)=(-1);
  g1(60,92)=1-params(67);
  g1(61,68)=1-params(55);
  g1(62,85)=1-params(50);
  g1(63,78)=1/y(78)-params(51)*1/y(78);
  g1(64,79)=1/y(79)-params(52)*1/y(79);
  g1(65,60)=1/y(60)-params(53)*1/y(60);
  g1(66,61)=1/y(61)-params(54)*1/y(61);
  g1(67,91)=1-params(65);
  g1(68,84)=(-1)-(-params(69));
  g1(69,19)=1-params(6);
  g1(70,20)=1-params(7);
  g1(71,21)=1-params(8);
  g1(72,22)=1-params(9);
  g1(73,80)=(-params(84));
  g1(73,116)=1;
  g1(73,117)=(-(1-params(84)));
  g1(74,117)=(-params(1));
  g1(74,119)=params(1);
  g1(75,4)=1;
  g1(76,81)=1;
  g1(77,83)=1;
  g1(78,84)=1;
  g1(79,52)=(-(1/y(53)));
  g1(79,53)=(-((-y(52))/(y(53)*y(53))));
  g1(79,94)=1;
  g1(80,45)=(-y(75));
  g1(80,75)=(-y(45));
  g1(80,95)=1;
  g1(81,59)=1;
  g1(81,65)=(-(y(92)*alpha_star__*1/y(93)*T1657));
  g1(81,76)=(-(y(92)*T1058*(neer_ss__*params(41)*T1945+r_f_ss__*params(83)*T1820)/Y_star_ss__));
  g1(81,77)=(-(y(92)*T1058*(neer_ss__*params(41)*T2311+r_f_ss__*params(83)*T2195)/Y_star_ss__));
  g1(81,92)=(-(alpha_star__*T1058));
  g1(81,93)=(-(y(92)*alpha_star__*T1657*(-y(65))/(y(93)*y(93))));
  g1(82,29)=(-(params(41)*y(116)));
  g1(82,59)=1;
  g1(82,67)=(-(y(80)*y(95)/y(80)));
  g1(82,95)=1-y(80)*(1+y(67))/y(80);
  g1(82,116)=(-(params(41)*y(29)));
  g1(83,3)=1;
  g1(83,68)=100;
  g1(83,73)=(-100);
  g1(84,2)=1;
  g1(84,68)=100;
  g1(84,74)=(-100);
  g1(85,1)=1;
  g1(85,66)=(-100);
  g1(85,68)=100;
  g1(86,26)=1;
  g1(86,66)=(-400);
  g1(87,27)=1;
  g1(87,74)=(-400);
  g1(88,10)=1;
  g1(88,76)=(-(100*(-(y(94)*(B_ss__*params(44)*T1880-K_b_ss__*T1880)/(B_ss__*B_ss__)))/(K_B_ss__*K_B_ss__)/T1096));
  g1(88,77)=(-(100*(-(y(94)*(B_ss__*params(44)*T2251-K_b_ss__*T2251)/(B_ss__*B_ss__)))/(K_B_ss__*K_B_ss__)/T1096));
  g1(88,94)=(-(100*1/K_B_ss__/T1096));
  g1(89,28)=1;
  g1(89,29)=(-(100*1/C_ss__/T1101));
  g1(89,76)=(-(100*(-(y(29)*T1945))/(C_ss__*C_ss__)/T1101));
  g1(89,77)=(-(100*(-(y(29)*T2311))/(C_ss__*C_ss__)/T1101));
  g1(90,23)=1;
  g1(90,73)=(-400);
  g1(91,24)=1;
  g1(91,70)=(-400);
  g1(92,25)=1;
  g1(92,68)=(-400);
  g1(93,9)=1;
  g1(93,56)=(-(100*1/q_h_ss__/T1118));
  g1(93,76)=(-(100*(-(y(56)*T1863))/(q_h_ss__*q_h_ss__)/T1118));
  g1(93,77)=(-(100*(-(y(56)*T2237))/(q_h_ss__*q_h_ss__)/T1118));
  g1(94,5)=1;
  g1(94,76)=(-(100*(-(y(86)*T1879))/(b_h_ss__*b_h_ss__)/T1123));
  g1(94,77)=(-(100*(-(y(86)*T2250))/(b_h_ss__*b_h_ss__)/T1123));
  g1(94,86)=(-(100*1/b_h_ss__/T1123));
  g1(95,6)=1;
  g1(95,76)=(-(100*(-(y(82)*T1830))/(b_e_ss__*b_e_ss__)/T1128));
  g1(95,77)=(-(100*(-(y(82)*T2209))/(b_e_ss__*b_e_ss__)/T1128));
  g1(95,82)=(-(100*1/b_e_ss__/T1128));
  g1(96,7)=1;
  g1(96,76)=(-(100*(-(y(87)*T1899))/(D_lv_ss__*D_lv_ss__)/T1133));
  g1(96,77)=(-(100*(-(y(87)*T2269))/(D_lv_ss__*D_lv_ss__)/T1133));
  g1(96,87)=(-(100*1/D_lv_ss__/T1133));
  g1(97,8)=1;
  g1(97,76)=(-(100*(-(y(88)*T1899))/(D_eu_ss__*D_eu_ss__)/T1138));
  g1(97,77)=(-(100*(-(y(88)*T2269))/(D_eu_ss__*D_eu_ss__)/T1138));
  g1(97,88)=(-(100*1/D_eu_ss__/T1138));
  g1(98,71)=(-400);
  g1(98,98)=1;
  g1(99,67)=(-400);
  g1(99,97)=1;
  g1(100,54)=(-(100*1/GDP_ss__/T1152));
  g1(100,76)=(-(100*(-(y(54)*(neer_ss__*params(41)*T1945+r_f_ss__*params(83)*T1820+(1-params(41))*T1945+params(31)*ZETA0__*T1820+params(32)*ZETA1__*(Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*T1820)+q_h_ss__*T1858+IH_ss__*T1863)))/(GDP_ss__*GDP_ss__)/T1152));
  g1(100,77)=(-(100*(-(y(54)*(neer_ss__*params(41)*T2311+r_f_ss__*params(83)*T2195+(1-params(41))*T2311+params(31)*(Y_ss__*T2123+ZETA0__*T2195)+params(32)*(QI__*T2133+ZETA1__*(Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*T2195))+q_h_ss__*T2233+IH_ss__*T2237)))/(GDP_ss__*GDP_ss__)/T1152));
  g1(100,99)=1;
  g1(101,49)=(-(100*1/c_e_ss__/T1157));
  g1(101,76)=(-(100*(-(y(49)*T1944))/(c_e_ss__*c_e_ss__)/T1157));
  g1(101,77)=(-(100*(-(y(49)*T2310))/(c_e_ss__*c_e_ss__)/T1157));
  g1(101,102)=1;
  g1(102,37)=(-(100*1/c_i_ss__/T1162));
  g1(102,76)=(-(100*(-(y(37)*(Y_ss__*T1779+CYPRIME__*T1820)))/(c_i_ss__*c_i_ss__)/T1162));
  g1(102,77)=(-(100*(-(y(37)*(Y_ss__*T2161+CYPRIME__*T2195)))/(c_i_ss__*c_i_ss__)/T1162));
  g1(102,103)=1;
  g1(103,30)=(-(100*1/c_p_ss__/T1167));
  g1(103,76)=(-(100*(-(y(30)*(Y_ss__*T1769+CY__*T1820)))/(c_p_ss__*c_p_ss__)/T1167));
  g1(103,77)=(-(100*(-(y(30)*(Y_ss__*T2148+CY__*T2195)))/(c_p_ss__*c_p_ss__)/T1167));
  g1(103,104)=1;
  g1(104,38)=(-(100*1/h_i_ss__/T1172));
  g1(104,76)=(-(100*(-(y(38)*T1876))/(h_i_ss__*h_i_ss__)/T1172));
  g1(104,77)=(-(100*(-(y(38)*(q_h_ss__*ZETA3__*(Y_ss__*T2161+CYPRIME__*T2195)-ZETA3__*c_i_ss__*T2237)/(q_h_ss__*q_h_ss__)))/(h_i_ss__*h_i_ss__)/T1172));
  g1(104,105)=1;
  g1(105,31)=(-(100*1/h_p_ss__/T1178));
  g1(105,76)=(-(100*(-(y(31)*(q_h_ss__*ZETA2__*(Y_ss__*T1769+CY__*T1820)-ZETA2__*c_p_ss__*T1863)/(q_h_ss__*q_h_ss__)))/(h_p_ss__*h_p_ss__)/T1178));
  g1(105,77)=(-(100*(-(y(31)*(q_h_ss__*ZETA2__*(Y_ss__*T2148+CY__*T2195)-ZETA2__*c_p_ss__*T2237)/(q_h_ss__*q_h_ss__)))/(h_p_ss__*h_p_ss__)/T1178));
  g1(105,106)=1;
  g1(106,57)=(-(100*1/i_c_ss__/T1183));
  g1(106,76)=(-(100*(-(y(57)*params(31)*ZETA0__*T1820))/(i_c_ss__*i_c_ss__)/T1183));
  g1(106,77)=(-(100*(-(y(57)*params(31)*(Y_ss__*T2123+ZETA0__*T2195)))/(i_c_ss__*i_c_ss__)/T1183));
  g1(106,107)=1;
  g1(107,58)=(-(100*1/i_h_ss__/T1188));
  g1(107,76)=(-(100*(-(y(58)*params(32)*ZETA1__*(Y_ss__*params(17)*(ZETA2__*T1769+CYPRIME__*T1754+ZETA3__*T1779)+QIY__*T1820)))/(i_h_ss__*i_h_ss__)/T1188));
  g1(107,77)=(-(100*(-(y(58)*params(32)*(QI__*T2133+ZETA1__*(Y_ss__*params(17)*(ZETA2__*T2148+ZETA3__*T2161)+QIY__*T2195))))/(i_h_ss__*i_h_ss__)/T1188));
  g1(107,108)=1;
  g1(108,47)=(-(100*1/IH_ss__/T1193));
  g1(108,76)=(-(100*(-(y(47)*T1858))/(IH_ss__*IH_ss__)/T1193));
  g1(108,77)=(-(100*(-(y(47)*T2233))/(IH_ss__*IH_ss__)/T1193));
  g1(108,109)=1;
  g1(109,55)=(-(100*1/J_b_ss__/T1198));
  g1(109,76)=(-(100*(-(y(55)*T1919))/(J_b_ss__*J_b_ss__)/T1198));
  g1(109,77)=(-(100*(-(y(55)*T2286))/(J_b_ss__*J_b_ss__)/T1198));
  g1(109,110)=1;
  g1(110,52)=(-(100*1/K_b_ss__/T1203));
  g1(110,76)=(-(100*(-(y(52)*params(44)*T1880))/(K_b_ss__*K_b_ss__)/T1203));
  g1(110,77)=(-(100*(-(y(52)*params(44)*T2251))/(K_b_ss__*K_b_ss__)/T1203));
  g1(110,111)=1;
  g1(111,89)=(-(100*1/params(79)/(y(89)/params(79))));
  g1(111,112)=1;
  g1(112,90)=(-(100*1/params(80)/(y(90)/params(80))));
  g1(112,113)=1;
  g1(113,53)=(-(100*1/B_ss__/T1218));
  g1(113,76)=(-(100*(-(y(53)*T1880))/(B_ss__*B_ss__)/T1218));
  g1(113,77)=(-(100*(-(y(53)*T2251))/(B_ss__*B_ss__)/T1218));
  g1(113,101)=1;
  g1(114,81)=(-(100*1/params(78)/(y(81)/params(78))));
  g1(114,100)=1;
  g1(115,84)=(-(100*1/y(84)));
  g1(115,118)=1;
  g1(116,76)=(-(100*(-(y(95)*params(83)*T1820))/(F_ss__*F_ss__)/T1233));
  g1(116,77)=(-(100*(-(y(95)*params(83)*T2195))/(F_ss__*F_ss__)/T1233));
  g1(116,95)=(-(100*1/F_ss__/T1233));
  g1(116,96)=1;
  g1(117,114)=1-params(81);
  g1(118,115)=1-params(82);
  g1(119,117)=(-1);
  g1(119,119)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],119,14161);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],119,1685159);
end
